<?php
App::uses('AppController', 'Controller');
/**
 * Users Controller
 *
 * @property User $User
 */
class UsersController extends AppController {

	public function initDB() {
		$group = $this->User->Group;
		//Allow admins to everything
		$group->id = 1;
		$this->Acl->deny($group, 'controllers');
		$this->Acl->allow($group, 'controllers/RapportsVisites');
		//allow managers to posts and widgets
		$group->id = 2;
		$this->Acl->deny($group, 'controllers');
		$this->Acl->allow($group, 'controllers/');
		$this->Acl->allow($group, 'controllers/Widgets');
		//allow users to only add and edit on posts and widgets
		$group->id = 3;
		$this->Acl->allow($group, 'controllers');
		//we add an exit to avoid an ugly "missing views" error message
		echo "all done";
		exit;
	}

/*
	public function sha1SaltForAll(){
		$users=$this->User->find('all');
		foreach($users as $user):
			$this->User->save($user['User']);
		endforeach;
	}
*/



	public function login(){
		$this->set('title_for_layout', 'Bienvenue sur la page de connexion');
		$this->layout='default';
		if($this->request->is('post')){
			if($this->Auth->login()){
				$this->redirect($this->Auth->redirect());
			}else{
				$this->Session->setFlash(__('Nom d\'utilisateur ou mot de passe incorrect, réessayer !'));
			}
		}
	}
	
	public function logout(){
		$this->redirect($this->Auth->logout());
	}
	
	public function statistiques(){
		$years = array(date('Y'), date('Y')-1, date('Y')-2);
		$this->set('years', $years);
		
		$this->loadModel('Offrir');
		$this->loadModel('Presentation');
		$this->loadModel('RapportsVisite');
		
		$countRapports[0] = $this->RapportsVisite->find('count', array('conditions' => array('YEAR(date)' => date('Y'))));
		$countRapports[1] = $this->RapportsVisite->find('count', array('conditions' => array('YEAR(date)' => date('Y')-1)));
		$countRapports[2] = $this->RapportsVisite->find('count', array('conditions' => array('YEAR(date)' => date('Y')-2)));
		$this->set('countRapports', $countRapports);
		
		$countOffrir[0] = $this->Offrir->find('count', array('conditions' => array('YEAR(Offrir.created)' => date('Y'))));
		$countOffrir[1] = $this->Offrir->find('count', array('conditions' => array('YEAR(Offrir.created)' => date('Y')-1)));
		$countOffrir[2] = $this->Offrir->find('count', array('conditions' => array('YEAR(Offrir.created)' => date('Y')-2)));
		$this->set('countOffrir', $countOffrir);
		
		$countPresentation[0] = $this->Presentation->find('count', array('conditions' => array('YEAR(Presentation.created)' => date('Y'))));
		$countPresentation[1] = $this->Presentation->find('count', array('conditions' => array('YEAR(Presentation.created)' => date('Y')-1)));
		$countPresentation[2] = $this->Presentation->find('count', array('conditions' => array('YEAR(Presentation.created)' => date('Y')-2)));
		$this->set('countPresentation', $countPresentation);
	}

/**
 * index method
 *
 * @return void
 */
	public function index() {
		$this->User->recursive = 0;
		$this->set('users', $this->paginate());
	}

/**
 * view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function view($id = null) {
		if (!$this->User->exists($id)) {
			throw new NotFoundException(__('Invalid user'));
		}
		$options = array('conditions' => array('User.' . $this->User->primaryKey => $id));
		$this->set('user', $this->User->find('first', $options));
	}

/**
 * add method
 *
 * @return void
 */
	public function add() {
		if ($this->request->is('post')) {
			$this->User->create();
			if ($this->User->save($this->request->data)) {
				$this->Session->setFlash(__('The user has been saved'));
				$this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The user could not be saved. Please, try again.'));
			}
		}
		$secteurs = $this->User->Secteur->find('list');
		$labos = $this->User->Labo->find('list');
		$groups=$this->User->Group->find('list');
		$this->set(compact('secteurs', 'groups', 'labos'));
	}

/**
 * edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
	public function edit($id = null) {
		if (!$this->User->exists($id)) {
			throw new NotFoundException(__('Invalid user'));
		}
		if ($this->request->is('post') || $this->request->is('put')) {
			if ($this->User->save($this->request->data)) {
				$this->Session->setFlash(__('The user has been saved'));
				$this->redirect(array('action' => 'index'));
			} else {
				$this->Session->setFlash(__('The user could not be saved. Please, try again.'));
			}
		} else {
			$options = array('conditions' => array('User.' . $this->User->primaryKey => $id));
			$this->request->data = $this->User->find('first', $options);
		}
		$secteurs = $this->User->Secteur->find('list');
		$labos = $this->User->Labo->find('list');
		$this->set(compact('secteurs', 'groups', 'labos'));
	}

/**
 * delete method
 *
 * @throws NotFoundException
 * @throws MethodNotAllowedException
 * @param string $id
 * @return void
 */
	public function delete($id = null) {
		$this->User->id = $id;
		if (!$this->User->exists()) {
			throw new NotFoundException(__('Invalid user'));
		}
		$this->request->onlyAllow('post', 'delete');
		if ($this->User->delete()) {
			$this->Session->setFlash(__('User deleted'));
			$this->redirect(array('action' => 'index'));
		}
		$this->Session->setFlash(__('User was not deleted'));
		$this->redirect(array('action' => 'index'));
	}
}
